@@ -1065,6 +1065,12 @@ Please contact the site administrator for assistance.';
     this.loadedFromElement = true;
   }
 
+   // check if the contents are to be generated by javascript
+   if (caption.match(/^javascript:/)) {
+     var jsFunctionCall = caption.substring(11);
+     caption = eval(jsFunctionCall);
+   }
+
   // check if iframes are allowed
   if (caption.match(/\<\s*iframe/i) && !this.allowIframes) {
     alert('Sorry: iframe elements '+notAllowed);
@@ -1087,7 +1093,7 @@ Please contact the site administrator for assistance.';
   this.currentHelpText = this.getContents(caption);
   this.loadedFromElement = false;
   
-  return this.currentHelpText;;
+  return this.currentHelpText;
 }
 
 
